// Inkludieren der NeoPixel-Bibliothek zur Steuerung des LED-Streifens
#include <Adafruit_NeoPixel.h>

// Pin-Konfigurationen für LED-Streifen und Ultraschallsensor
#define PIN_LED_STRIP 5
#define PIN_TRIG 3
#define PIN_ECHO 4
#define NUM_LEDS 30 // Anzahl der LEDs auf dem Streifen

// Initialisierung des NeoPixel-Objekts mit Pin-Konfiguration und LED-Anzahl
Adafruit_NeoPixel strip = Adafruit_NeoPixel(NUM_LEDS, PIN_LED_STRIP, NEO_GRB + NEO_KHZ800);

// Initialisierung der Setup-Funktion für das Festlegen der Pin-Modi und des NeoPixel-Streifens
void setup() {
  pinMode(PIN_TRIG, OUTPUT);
  pinMode(PIN_ECHO, INPUT);
  strip.begin(); // Start des NeoPixel-Streifens
  strip.show();  // Schaltet alle LEDs beim Start aus
}

// Die Hauptprogrammschleife
void loop() {
  // Überprüft den Abstand mit dem Ultraschallsensor
  float distance = checkDistance();

  // Wenn der Abstand weniger als 20 cm beträgt, führt es den roten Strobe-Effekt aus
  if (distance < 20) {
    redStrobeEffect();
  } 
  // Wenn der Abstand größer als 50 cm ist, schaltet es alle LEDs blau
  else if (distance > 50) {
    setAllBlue();
  }
}

// Funktion zum Messen des Abstands mit dem Ultraschallsensor und Rückgabe des gemessenen Abstands
float checkDistance() {
  // Sendet einen Ultraschallimpuls aus
  digitalWrite(PIN_TRIG, LOW);
  delayMicroseconds(2);
  digitalWrite(PIN_TRIG, HIGH);
  delayMicroseconds(10);
  digitalWrite(PIN_TRIG, LOW);
  
  // Misst die Impulsdauer und konvertiert sie in einen Abstand in Zentimetern
  float duration = pulseIn(PIN_ECHO, HIGH);
  float distance = (duration / 2) / 29.1;
  
  // Gibt den gemessenen Abstand zurück
  return distance;
}

// Funktion für den roten Strobe-Effekt auf dem LED-Streifen
void redStrobeEffect() {
  // Schaltet den Strobe-Effekt ein und aus
  strip.fill(strip.Color(255, 0, 0), 0, NUM_LEDS);
  strip.show();
  delay(50);
  strip.clear();
  strip.show();
  delay(50);
}

// Funktion um alle LEDs blau zu machen
void setAllBlue() {
  strip.fill(strip.Color(0, 0, 255), 0, NUM_LEDS);
  strip.show();
}

